pub enum EphemeronMutationError {
Allocation(EdgeAllocationError),
UnknownEdge(EdgeId),
WrongKind {
edge: EdgeId,
actual: EdgeKind,
},
EntryChanged {
expected_key: ManagedId,
expected_value: ManagedId,
actual_key: ManagedId,
actual_value: ManagedId,
},
}Expand description
A failed checked mutation of an ephemeron entry.
Variants
Allocation(EdgeAllocationError)
Allocating a stable identity for a new entry failed.
UnknownEdge(EdgeId)
The requested identity is not a live ephemeron entry of this node.
WrongKind
The identity is live, but has different collection semantics.
Fields
EntryChanged
The entry exists, but no longer contains the caller’s expected pair.