pub fn mutable_vector_value(value: &Value) -> Result<&MutableVector>Expand description
Borrow the MutableVector behind value, or error if it is not one.
pub fn mutable_vector_value(value: &Value) -> Result<&MutableVector>Borrow the MutableVector behind value, or error if it is not one.