pub struct EdgeLimits { /* private fields */ }Expand description
Hard limits for the outgoing edges owned by one ManagedNode.
Implementations
Sourceimpl EdgeLimits
impl EdgeLimits
Sourcepub const DEFAULT: Self
pub const DEFAULT: Self
Default per-node hard cap. Per-kind caps share the same ceiling while the total cap prevents their sum from exceeding it.